@@ -13,7 +13,7 @@ use Time::HiRes qw(time);
 
 use base qw(Alzabo::Table);
 
-$VERSION = sprintf '%2d.%02d', q$Revision: 1.83 $ =~ /(\d+)\.(\d+)/;
+$VERSION = sprintf '%2d.%02d', q$Revision: 1.90 $ =~ /(\d+)\.(\d+)/;
 
 sub insert
 {
@@ -194,7 +194,8 @@ sub one_row
     }
 
     my @return = $self->schema->driver->one_row( sql => $sql->sql,
-						 bind => $sql->bind );
+						 bind => $sql->bind )
+	or return;
 
     my $time = time;
 
@@ -373,6 +374,8 @@ sub add_group
 {
     my $self = shift;
 
+    return unless $Alzabo::ObjectCache::VERSION;
+
     validate_pos( @_, ( { isa => 'Alzabo::Column' } ) x @_ );
 
     my @names = map { $_->name } @_;
@@ -434,7 +437,9 @@ sub column
 	    $col = $col->alias_clone( table => $self );
 	    my $index = $self->{columns}->Indices($name);
 	    $self->{columns}->Replace( $index, $col, $name );
-	}
+
+            delete $self->{pk_array} if $col->is_primary_key;
+        }
 
 	return $col;
     }
@@ -446,7 +451,9 @@ sub column
 
 sub alias_name
 {
-    return $_[0]->{alias_name} || $_[0]->name;
+    # intentionally don't call $_[0]->name for a noticeable
+    # performance boost
+    return $_[0]->{alias_name} || $_[0]->{name};
 }
 
 sub real_table
@@ -454,6 +461,19 @@ sub real_table
     return $_[0]->{real_table} || $_[0];
 }
 
+# This gets called a _lot_ so doing this sort of 'memoization' helps
+sub primary_key
+{
+    my $self = shift;
+
+    $self->{pk_array} ||= [ $self->SUPER::primary_key ];
+
+    return ( wantarray ?
+             @{ $self->{pk_array} } :
+             $self->{pk_array}->[0]
+           );
+}
+
 1;
 
 __END__
@@ -855,8 +875,8 @@ methods that were generated by Alzabo::MethodMaker.
 
 However, B<this object should not be used outside the context of a
 join query> because the results will be unpredictable.  In addition,
-B<the column objects that the alias returns should also not be used
-outside of the context of a join>.
+B<the column objects that the aliased table object returns should also
+not be used outside of the context of a join>.
 
 =for pod_merge schema
 
@@ -933,6 +953,9 @@ L<C<Alzabo::Runtime::Row>|Alzabo::Runtime::Row> objects fetch this
 data as soon as they are created, as well as immediately after they
 know they have been expired in the cache.
 
+This method is only effective when caching is turned on, as otherwise
+prefetched data may be stale and we would never know this.
+
 NOTE: It is pointless (though not an error) to give primary key column
 here as these are always prefetched (in a sense).
 
@@ -948,6 +971,9 @@ any column in the group is fetched from the database, then they will
 all be fetched.  Otherwise column are always fetched singly.
 Currently, a column cannot be part of more than one group.
 
+This method is only effective when caching is turned on, as otherwise
+group-fetched data may be stale and we would never know this.
+
 NOTE: It is pointless to include a column that was given to the
 L<C<set_prefetch>|Alzabo::Runtime::Table/set_prefetch (Alzabo::Column
 objects)> method in a group here, as it always fetched as soon as
